API
===

.. automodule:: python3_pip_skeleton

    ``python3_pip_skeleton``
    -----------------------------------

This is the internal API reference for python3_pip_skeleton

.. data:: python3_pip_skeleton.__version__
    :type: str

    Version number as calculated by https://github.com/pypa/setuptools_scm
